@@ -5,12 +5,7 @@ from datetime import date
 from pathlib import Path
 from subprocess import PIPE, Popen
 
-import boto3
-from google.cloud import storage
-from google.oauth2 import service_account
-
 from postgres_backup.schemas import CloudProviders, CloudStorageType
-from postgres_backup.upload import AWSStorage, GCStorage
 from postgres_backup.utils import logger, settings
 
 
@@ -40,7 +35,7 @@ class Backup:
 
     def create(
         self,
-        local_file_path: typing.Optional[str] = '',
+        local_file_path: typing.Optional[str] = '.',
         out_file_name: typing.Union[str, Path] = 'backup',
         out_file_extension: typing.Union[str, Path] = '.gz',
         table_names: typing.Optional[typing.List[str]] = [],
@@ -109,6 +104,11 @@ class Backup:
         file_name = self.file_name if self.file_name else file_name
 
         if provider == 'google_cloud_storage':
+            from google.cloud import storage
+            from google.oauth2 import service_account
+
+            from postgres_backup.upload import GCStorage
+
             credentials = service_account.Credentials.from_service_account_info(
                 google_cloud_certification
             )
@@ -130,12 +130,16 @@ class Backup:
 
         elif provider == 'amazon_web_services':
             # Create a Boto3 Session
+            import boto3
+
             session = boto3.Session(
                 aws_server_public_key=aws_server_public_key,
                 aws_server_private_key=aws_server_private_key,
                 region_name=region_name
             )
 
+            from postgres_backup.upload import AWSStorage
+
             # Select the resource for which we want to work
             s3_resource = session.resource('s3')
 
