@@ -124,6 +124,6 @@ class GCStorage:
         blob.upload_from_filename(local_file_path + '/' + file_name)
 
         if clean:
-            os.remove(local_file_path + file_name)
+            os.remove(local_file_path + '/' + file_name)
 
         return True
